@@ -26,7 +26,7 @@ project = u'travis2docker'
 year = '2016'
 author = u'Vauxoo'
 copyright = '{0}, {1}'.format(year, author)
-version = release = u'6.4.11'
+version = release = u'6.4.16'
 
 pygments_style = 'trac'
 templates_path = ['.']
@@ -34,12 +34,8 @@ extlinks = {
     'issue': ('https://github.com/vauxoo/travis2docker/issues/%s', '#'),
     'pr': ('https://github.com/vauxoo/travis2docker/pull/%s', 'PR #'),
 }
-# on_rtd is whether we are on readthedocs.org
-on_rtd = os.environ.get('READTHEDOCS', None) == 'True'
-
-if not on_rtd:  # only set the theme if we're building docs locally
-    html_theme = 'sphinx_rtd_theme'
 
+html_theme = 'sphinx_rtd_theme'
 html_use_smartypants = True
 html_last_updated_fmt = '%b %d, %Y'
 html_split_index = False
