@@ -77,6 +77,7 @@ class Travis2Docker(object):
         runs_at_the_end_script=None,
         build_env_args=None,
         deployv=None,
+        build_extra_steps=None,
     ):
         self._python_versions = []
         self.curr_work_path = None
@@ -87,6 +88,7 @@ class Travis2Docker(object):
         self.deployv = deployv
         self.runs_at_the_end_script = ["sleep 2"] if runs_at_the_end_script is None else runs_at_the_end_script
         self.variables_sh_data = {}
+        self.build_extra_steps = build_extra_steps
         if deployv:
             self.variables_sh_data = {
                 var.lower(): value for _, _, var, value in self.re_export.findall(os_kwargs['variables_sh'])
@@ -304,6 +306,7 @@ class Travis2Docker(object):
                     copies = []
                     for copy_path, dest in self.copy_paths:
                         copies.append((self.copy_path(copy_path), dest))
+                    self.set_authorized_key()
                     kwargs = {
                         'runs': [],
                         'copies': copies,
@@ -316,6 +319,7 @@ class Travis2Docker(object):
                         'sources': [],
                         'rvm_env_path': rvm_env_relpath,
                         'build_env_args': self.build_env_args,
+                        'build_extra_steps': self.build_extra_steps,
                     }
                     with open(curr_dockerfile, "w") as f_dockerfile, open(entryp_path, "w") as f_entrypoint, open(
                         rvm_env_path, "w"
@@ -378,3 +382,25 @@ class Travis2Docker(object):
         else:
             raise UserWarning("Just directory or file is supported to copy [%s]" % src)
         return os.path.relpath(dest_path, self.curr_work_path)
+
+    def set_authorized_key(self):
+        ssh_dir = os.path.expanduser("~/.ssh")
+        ed_key = os.path.join(ssh_dir, "id_ed25519.pub")
+        rsa_key = os.path.join(ssh_dir, "id_rsa.pub")
+
+        to_copy = False
+        if os.path.isfile(ed_key):
+            to_copy = ed_key
+        elif os.path.isfile(rsa_key):
+            print("RSA keys are deprecated, consider changing to ed25519")
+            to_copy = rsa_key
+
+        if not to_copy:
+            print("No public key found. No key added to ~/.ssh/authorized_keys. SSH login won't work.")
+            return
+
+        with open(to_copy, "r", encoding="utf-8") as key_fd:
+            pub_key = key_fd.read()
+
+        with open(os.path.join(self.curr_work_path, ".ssh", "authorized_keys"), "w", encoding="utf-8") as auth_fd:
+            auth_fd.write(pub_key)
